SAW class

Constructors

SAW()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateSawMatrix({required List<WeightedDecisionAlternative> listAlternative, required List<WeightedDecisionCriteria> listCriteria}) Future<List<WeightedDecisionMatrix>>
GENERATE SAW MATRIX
getResultWithExistingMatrix({required List<WeightedDecisionMatrix> sawMatrix}) Future<List<WeightedDecisionResult>>
CALCULATE RESULT WITH EXISTING MATRIX
getSawResult({required List<WeightedDecisionMatrix> matrix}) Future<List<WeightedDecisionResult>>
CALCULATE SAW RESULT
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateSawMatrix({required List<WeightedDecisionMatrix> currentMatrix, required String? matrixId, required String? ratingsId, required double value}) Future<List<WeightedDecisionMatrix>>
UPDATE SAW MATRIX

Operators

operator ==(Object other) bool
The equality operator.
inherited