GenerateTopsisMatrixUsecase class
Constructors
- GenerateTopsisMatrixUsecase(TopsisRepository _repository)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
{required List< WeightedDecisionAlternative> listAlternative, required List<WeightedDecisionCriteria> listCriteria}) → Future<TopsisRawMatrix> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited