TOPSIS class
Constructors
- TOPSIS()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateTopsisMatrix(
{required List< WeightedDecisionAlternative> listAlternative, required List<WeightedDecisionCriteria> listCriteria}) → Future<TopsisRawMatrix> - GENERATE TOPSIS MATRIX
-
getTopsisResult(
{required TopsisRawMatrix matrix}) → Future< List< WeightedDecisionResult> > - CALCULATE TOPSIS RESULT
-
getTopsisResultWithExistingMatrix(
{required TopsisRawMatrix matrix}) → Future< List< WeightedDecisionResult> > - CALCULATE RESULT WITH EXISTING MATRIX
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateTopsisMatrix(
{required TopsisRawMatrix currentRawMatrix, required String? matrixId, required String? ratingsId, required double value}) → Future< TopsisRawMatrix> - UPDATE TOPSIS MATRIX
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited